@@ -1,7 +1,7 @@
 ##' Estimation of concordance in bivariate competing risks data
 ##'
 ##' @title Estimation of concordance in bivariate competing risks data
-##' @param formula Formula with left-hand-side being a \code{Hist} object (see example below) and the left-hand-side specying the covariate structure
+##' @param formula Formula with left-hand-side being a \code{Event} object (see example below) and the left-hand-side specying the covariate structure
 ##' @param data Data frame
 ##' @param cause Causes (default (1,1)) for which to estimate the bivariate cumulative incidence
 ##' @param cens The censoring code
@@ -23,6 +23,16 @@
 ##' @param ... Additional arguments to lower level functions
 ##' @author Thomas Scheike, Klaus K. Holst
 ##' @export
+##' @examples
+##' 
+##' data(prt) ## Prostate data example (sim)
+##' ## Bivariate competing risk, concordance estimates
+##' p33 <- bicomprisk(Event(time,status)~strata(zyg)+id(id),
+##'                   data=prt,cause=c(2,2),return.data=1)
+##'  
+##' p33mz <- p33$model$"MZ"$comp.risk
+##' ## Concordance
+##' plot(p33mz,ylim=c(0,0.1),axes=FALSE); axis(2); axis(1)
 bicomprisk <- function(formula, data, cause=c(1,1), cens=0, causes, indiv, 
  strata=NULL, id,num, max.clust=1000, marg=NULL,se.clusters=NULL,
  prodlim=FALSE,messages=TRUE,model,return.data=0,uniform=0,conservative=1,resample.iid=1,...) {
@@ -35,6 +45,13 @@ bicomprisk <- function(formula, data, cause=c(1,1), cens=0, causes, indiv,
                      "-strata(",paste(formulaStrata,collapse="+"),")",
                      "-indiv(",paste(formulaIndiv,collapse="+"),")")
   formula <- update(formula,formulaSt)
+
+  ### ts  11/10 
+  ## if (substr(as.character(formula)[2],1,4)=="Hist") {
+  ##     stop("Since version : The left hand side of the formula must be specified as 
+  ##     Event(time, event) or with non default censoring codes Event(time, event, cens.code=0).")
+  ## }
+
   if (!is.null(formulaId)) {
     id <- formulaId
     mycall$id <- id
@@ -180,7 +197,7 @@ bicomprisk <- function(formula, data, cause=c(1,1), cens=0, causes, indiv,
 
   if (return.data==2) return(list(data=mydata)) else {
   if (!prodlim) {
-    ff <- paste("Hist(",timevar,",",causes,",cens.code=",cens,") ~ 1",sep="")
+    ff <- paste("Event(",timevar,",",causes,",cens.code=",cens,") ~ 1",sep="")
     if (length(c(covars,indiv))>0) {
       xx <- c(covars,indiv2)
      for (i in seq_len(length(xx)))
@@ -201,6 +218,7 @@ bicomprisk <- function(formula, data, cause=c(1,1), cens=0, causes, indiv,
     padd <- predict(add,X=1,se=1,uniform=uniform,resample.iid=resample.iid)
     padd$cluster.names <- lse.clusters
   } else {
+      if (!require(prodlim)) stop("prodlim requested but not installed")
     ff <- as.formula(paste("Hist(",timevar,",",causes,")~",paste(c("1",covars,indiv2),collapse="+")))
     padd <- prodlim::prodlim(ff,data=mydata)
   }
