@@ -1,9 +1,9 @@
 ##' Liability-threshold model for twin data
 ##'
-##' @aliases biprobit twinlm.time
+##' @aliases bptwin twinlm.time bptwin.time
 ##' @title Liability model for twin data
 ##' @seealso \code{\link{twinlm}}, \code{\link{twinlm.time}}, \code{\link{twinlm.strata}}, \code{\link{twinsim}}
-##' @param formula Formula specifying effects of covariates on the response.
+##' @param x Formula specifying effects of covariates on the response.
 ##' @param data \code{data.frame} with one observation pr row. In
 ##'     addition a column with the zygosity (DZ or MZ given as a factor) of
 ##'     each individual much be
@@ -16,7 +16,7 @@
 ##' corresponding to the dyzogitic twins. 
 ##' @param group Optional. Variable name defining group for interaction analysis (e.g., gender)
 ##' @param num Optional twin number variable
-##' @param weight Weight matrix if needed by the chosen estimator (IPCW)
+##' @param weights Weight matrix if needed by the chosen estimator (IPCW)
 ##' @param biweight Function defining the bivariate weight in each cluster
 ##' @param strata Strata
 ##' @param messages Control amount of messages shown 
@@ -26,7 +26,7 @@
 ##'     environmental factors, dominant
 ##'     genetic factors, unique environmental factors).
 ##' @param eqmean Equal means (with type="cor")?
-##' @param pairsonly Include complete pairs only?
+##' @param pairs.only Include complete pairs only?
 ##' @param stderr Should standard errors be calculated?
 ##' @param robustvar If TRUE robust (sandwich) variance estimates of the variance are used
 ##' @param p Parameter vector p in which to evaluate log-Likelihood and score function
@@ -47,18 +47,18 @@
 ##'              id="tvparnr",zyg="zyg",DZ="dz",type="ae")
 ##' summary(b0)
 ##' }
-bptwin <- function(formula, data, id, zyg, DZ, group=NULL,
+bptwin <- function(x, data, id, zyg, DZ, group=NULL,
                    num=NULL,
-                   weight=NULL,
+                   weights=NULL,
                    biweight=function(x) 1/min(x),
                    strata=NULL,
                    messages=1,
                    control=list(trace=0),
                    type="ace",
                    eqmean=TRUE,
-                   pairsonly=FALSE,
+                   pairs.only=FALSE,
                    samecens=TRUE,
-                   allmarg=samecens&!is.null(weight),
+                   allmarg=samecens&!is.null(weights),
                    stderr=TRUE,                  
                    robustvar=TRUE,                   
                    p, indiv=FALSE,
@@ -70,10 +70,10 @@ bptwin <- function(formula, data, id, zyg, DZ, group=NULL,
 ###{{{ setup
 
   mycall <- match.call()
-  formulaId <- unlist(Specials(formula,"cluster"))
-  formulaStrata <- unlist(Specials(formula,"strata"))
+  formulaId <- unlist(Specials(x,"cluster"))
+  formulaStrata <- unlist(Specials(x,"strata"))
   formulaSt <- paste("~.-cluster(",formulaId,")-strata(",paste(formulaStrata,collapse="+"),")")
-  formula <- update(formula,formulaSt)
+  formula <- update(x,formulaSt)
   if (!is.null(formulaId)) {
     id <- formulaId
     mycall$id <- id
@@ -106,7 +106,7 @@ bptwin <- function(formula, data, id, zyg, DZ, group=NULL,
 ##################################################
 ### No strata
   if (is.null(control$method)) {
-      if (!samecens & !is.null(weight)) {
+      if (!samecens & !is.null(weights)) {
         control$method <- "bhhh"
       } else {
         if (suppressWarnings(suppressPackageStartupMessages(require(ucminf)))) {
@@ -123,7 +123,7 @@ bptwin <- function(formula, data, id, zyg, DZ, group=NULL,
   if (sum(idtab>2)) stop("More than two individuals with the same id ")
 
   ##  suppressMessages(browser())
-  if (pairsonly) {
+  if (pairs.only) {
     data <- data[as.character(data[,id])%in%names(idtab)[idtab==2],]
     idtab <- table(data[,id])
   }
@@ -159,15 +159,15 @@ bptwin <- function(formula, data, id, zyg, DZ, group=NULL,
 
 
   ## ff <- paste(as.character(formula)[3],"+",
-  ##             paste(c(id,zyg,weight,num),collapse="+"))
+  ##             paste(c(id,zyg,weights,num),collapse="+"))
   ## ff <- paste("~",yvar,"+",ff)
   ##formula0 <- as.formula(ff)
   opt <- options(na.action="na.pass")
   ##  Data <- model.matrix(formula0,data)
-  Data <- cbind(model.matrix(formula,data),data[,c(yvar,id,zyg,weight,num)])
+  Data <- cbind(model.matrix(formula,data),data[,c(yvar,id,zyg,weights,num)])
   options(opt)
-  ## rnames1 <- setdiff(colnames(Data),c(yvar,time,id,weight,zyg))
-  rnames1 <- setdiff(colnames(Data),c(yvar,id,weight,zyg,num))
+  ## rnames1 <- setdiff(colnames(Data),c(yvar,time,id,weights,zyg))
+  rnames1 <- setdiff(colnames(Data),c(yvar,id,weights,zyg,num))
   nx <- length(rnames1) 
   if (nx==0) stop("Zero design not allowed")
   
@@ -256,8 +256,8 @@ bptwin <- function(formula, data, id, zyg, DZ, group=NULL,
   rmidx <- c(id,yidx,zyg)
     
   W0 <- W1 <- W2 <- NULL
-  if (!is.null(weight)) {
-    widx <- paste(weight,1:2,sep=".")
+  if (!is.null(weights)) {
+    widx <- paste(weights,1:2,sep=".")
     rmidx <- c(rmidx,widx)
     W0 <- as.matrix(Wide[which(Wide[,zyg]==0),widx,drop=FALSE])
     W1 <- as.matrix(Wide[which(Wide[,zyg]==1),widx,drop=FALSE])
@@ -288,9 +288,9 @@ bptwin <- function(formula, data, id, zyg, DZ, group=NULL,
 
   N <- cbind(length(idx0),length(idx1),length(idx2)); 
   N <- cbind(N,
-             2*nrow(MyData0$Y0)+if (!pairsonly) NROW(MyData0$Y0_marg) else 0, 
-             2*nrow(MyData1$Y0)+if (!pairsonly) NROW(MyData1$Y0_marg) else 0,
-             2*nrow(MyData2$Y0)+if (!pairsonly) NROW(MyData2$Y0_marg) else 0,
+             2*nrow(MyData0$Y0)+if (!pairs.only) NROW(MyData0$Y0_marg) else 0, 
+             2*nrow(MyData1$Y0)+if (!pairs.only) NROW(MyData1$Y0_marg) else 0,
+             2*nrow(MyData2$Y0)+if (!pairs.only) NROW(MyData2$Y0_marg) else 0,
              NROW(MyData0$Y0),NROW(MyData1$Y0),NROW(MyData2$Y0))
 
   
@@ -298,7 +298,7 @@ bptwin <- function(formula, data, id, zyg, DZ, group=NULL,
   rownames(N) <- rep("",nrow(N))
   if (!OSon) N <- N[,-c(3,6,9),drop=FALSE]
   
-  if (samecens & !is.null(weight)) {
+  if (samecens & !is.null(weights)) {
     MyData0$W0 <- cbind(apply(MyData0$W0,1,biweight))
     if (!is.null(MyData0$Y0_marg))
       MyData0$W0_marg <- cbind(apply(MyData0$W0_marg,1,biweight))
@@ -384,7 +384,7 @@ bptwin <- function(formula, data, id, zyg, DZ, group=NULL,
                              Mu0,
                              S$Sigma0,dS0,Y0,XX0,W0,!is.null(W0),samecens))
 
-    if (!is.null(MyData0$Y0_marg) &&!pairsonly) {
+    if (!is.null(MyData0$Y0_marg) &&!pairs.only) {
       mum <- with(MyData0, XX0_marg%*%b00)
       dSmarg <- dS0[,1,drop=FALSE]
        U_marg <- with(MyData0, .Call("uniprobit",
@@ -401,7 +401,7 @@ bptwin <- function(formula, data, id, zyg, DZ, group=NULL,
     U1 <- with(MyData1, .Call("biprobit0",
                              Mu1,
                              S$Sigma1,dS1,Y0,XX0,W0,!is.null(W0),samecens))
-    if (!is.null(MyData1$Y0_marg) &&!pairsonly) {
+    if (!is.null(MyData1$Y0_marg) &&!pairs.only) {
       mum <- with(MyData1, XX0_marg%*%b11)
       dSmarg <- dS1[,1,drop=FALSE]
       U_marg <- with(MyData1, .Call("uniprobit",
@@ -419,7 +419,7 @@ bptwin <- function(formula, data, id, zyg, DZ, group=NULL,
       U2 <- with(MyData2, .Call("biprobit0",
                                 Mu2,
                                 S$Sigma2,S$dS2,Y0,XX0,W0,!is.null(W0),samecens))
-      if (!is.null(MyData2$Y0_marg) &&!pairsonly) {
+      if (!is.null(MyData2$Y0_marg) &&!pairs.only) {
         mum <- with(MyData2, XX0_marg%*%b22)
         dSmarg <- S$dS2[,1,drop=FALSE]
         U_marg <- with(MyData2, .Call("uniprobit",
@@ -553,7 +553,7 @@ bptwin <- function(formula, data, id, zyg, DZ, group=NULL,
                optim=optim(p0,fn=f0,gr=g0,control=control[ucminfopt]),
                ucminf=,
                quasi=,
-               gradient=ucminf(p0,fn=f0,gr=g0,control=control[ucminfopt],hessian=0),
+               gradient=ucminf::ucminf(p0,fn=f0,gr=g0,control=control[ucminfopt],hessian=0),
                ## ,
                ## bhhh={
                ##   controlnr <- list(stabil=FALSE,
@@ -577,12 +577,13 @@ bptwin <- function(formula, data, id, zyg, DZ, group=NULL,
     UU <- U(op$par,indiv=TRUE)    
     I <- -numDeriv::jacobian(U,op$par)
     tol <- 1e-15
-    V <- Inverse(I,tol)
+    iI <- Inverse(I,tol)
+    V <- iI
     sqrteig <- attributes(V)$sqrteig
     J <- NULL
     if (robustvar) {
       J <- crossprod(UU)
-      V <- V%*%J%*%V
+      V <- iI%*%J%*%iI
     }
     if (any(sqrteig<tol)) warning("Near-singular covariance matrix (pseudo-inverse used)")
   } else {
@@ -629,7 +630,7 @@ bptwin <- function(formula, data, id, zyg, DZ, group=NULL,
   
   npar[unlist(lapply(npar,length))==0] <- 0
 
-  val <- list(coef=cc,vcov=V,I=I,score=UU,logLik=attributes(UU)$logLik,opt=op,
+  val <- list(coef=cc,vcov=V,bread=iI,I=I,score=UU,logLik=attributes(UU)$logLik,opt=op,
               id=Wide[,id], model.frame=Wide,
               Sigma0=S$Sigma0, Sigma1=S$Sigma1, Sigma2=S$Sigma2,
               dS0=dS0, dS1=dS1, dS2=dS2,
@@ -649,7 +650,7 @@ bptwin <- function(formula, data, id, zyg, DZ, group=NULL,
 
 ###}}} return
 
-##' @S3method model.frame bptwin
+##' @export
 model.frame.bptwin <- function(formula,...) {
     formula$model.frame
 }
